# Changelog

## [2.8.0](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.6...client-v2.8.0) (2025-09-15)


### Features

* **client:** update client feature ([41963ac](https://github.com/AEGIS-GAME/aegis/commit/41963ac38061bdfd20b010933603e7a94a80a10e))


### Bug Fixes

* client jsut checks version mismatch, aegis update just downloads ([85877fa](https://github.com/AEGIS-GAME/aegis/commit/85877fa7f45afe54710a6d071553e8604dc96967))
* **client:** dismissal of update banner if u wanna ([6279ff0](https://github.com/AEGIS-GAME/aegis/commit/6279ff007d1e76a6adf3c8e9f97d5cf0a5e7cc35))
* **client:** open "view on github" in default browser instead of electron ([b4684c1](https://github.com/AEGIS-GAME/aegis/commit/b4684c16ba3e80680ae67fea05570daa95334293))
* **client:** show aegis version in client "about" section in settings ([31f523b](https://github.com/AEGIS-GAME/aegis/commit/31f523bc2f084a2b862d0798e77ca6a38fbca2d3))
* **client:** wrong api ([61517ba](https://github.com/AEGIS-GAME/aegis/commit/61517baf84e0dc34a62ccc6c254daa11d0d988bf))
* using client-version.txt file for client version ([3fa68b1](https://github.com/AEGIS-GAME/aegis/commit/3fa68b1a468199095fc9571f15172c8c0c46f65e))

## [2.7.6](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.5...client-v2.7.6) (2025-09-15)


### Miscellaneous Chores

* **release:** release 2.7.6 ([c29bbe6](https://github.com/AEGIS-GAME/aegis/commit/c29bbe63290d54a2eb0ab313a30b50c1fe10713f))

## [2.7.5](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.4...client-v2.7.5) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.5 ([5531a56](https://github.com/AEGIS-GAME/aegis/commit/5531a566878ee494d18dac37d4f7d54b3b2273e5))

## [2.7.4](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.3...client-v2.7.4) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.4 ([2b45653](https://github.com/AEGIS-GAME/aegis/commit/2b45653e3cf530ad437b13365e86cc6691fdfe4e))

## [2.7.3](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.2...client-v2.7.3) (2025-09-14)


### Miscellaneous Chores

* **release:** release 2.7.3 ([0259bbb](https://github.com/AEGIS-GAME/aegis/commit/0259bbb85e855f16d0ea1550f98c29abbc113cc1))

## [2.7.2](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.1...client-v2.7.2) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.2 ([6408364](https://github.com/AEGIS-GAME/aegis/commit/64083645be9da4aa46934313f9b4cba02c0ca6b9))

## [2.7.1](https://github.com/AEGIS-GAME/aegis/compare/client-v2.7.0...client-v2.7.1) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.1 ([9d57c24](https://github.com/AEGIS-GAME/aegis/commit/9d57c2484cbb0bf5664c0dd25f7965a8cab027d2))

## [2.7.0](https://github.com/AEGIS-GAME/aegis/compare/client-v2.6.4...client-v2.7.0) (2025-09-12)


### Miscellaneous Chores

* **release:** release 2.7.0 ([f606992](https://github.com/AEGIS-GAME/aegis/commit/f606992695d07dded3787febced2586ca08e80e2))

## [2.6.4](https://github.com/AEGIS-GAME/aegis/compare/client-v2.6.3...client-v2.6.4) (2025-09-12)


### Bug Fixes

* **tryign to force a release:** hate google ([#50](https://github.com/AEGIS-GAME/aegis/issues/50)) ([93179c4](https://github.com/AEGIS-GAME/aegis/commit/93179c4935cf98ee3b50197d0a60b034db0905fd))
